
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __LIBMBIM_GLIB_FLAG_TYPES_H__
#define __LIBMBIM_GLIB_FLAG_TYPES_H__
#include "mbim-uuid.h"
#include "mbim-cid.h"
#include "mbim-message.h"
#include "mbim-enums.h"
#include "mbim-tlv.h"

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-enums.h" */
GType mbim_cellular_class_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CELLULAR_CLASS (mbim_cellular_class_get_type ())

/* Define type-specific symbols */
#define __MBIM_CELLULAR_CLASS_IS_FLAGS__

/**
 * mbim_cellular_class_build_string_from_mask:
 * @mask: bitmask of MbimCellularClass values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimCellularClass in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_cellular_class_build_string_from_mask (MbimCellularClass mask);
GType mbim_sim_class_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SIM_CLASS (mbim_sim_class_get_type ())

/* Define type-specific symbols */
#define __MBIM_SIM_CLASS_IS_FLAGS__

/**
 * mbim_sim_class_build_string_from_mask:
 * @mask: bitmask of MbimSimClass values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimSimClass in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_sim_class_build_string_from_mask (MbimSimClass mask);
GType mbim_data_class_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DATA_CLASS (mbim_data_class_get_type ())

/* Define type-specific symbols */
#define __MBIM_DATA_CLASS_IS_FLAGS__

/**
 * mbim_data_class_build_string_from_mask:
 * @mask: bitmask of MbimDataClass values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimDataClass in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_data_class_build_string_from_mask (MbimDataClass mask);
GType mbim_sms_caps_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_CAPS (mbim_sms_caps_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_CAPS_IS_FLAGS__

/**
 * mbim_sms_caps_build_string_from_mask:
 * @mask: bitmask of MbimSmsCaps values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimSmsCaps in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_sms_caps_build_string_from_mask (MbimSmsCaps mask);
GType mbim_ctrl_caps_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CTRL_CAPS (mbim_ctrl_caps_get_type ())

/* Define type-specific symbols */
#define __MBIM_CTRL_CAPS_IS_FLAGS__

/**
 * mbim_ctrl_caps_build_string_from_mask:
 * @mask: bitmask of MbimCtrlCaps values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimCtrlCaps in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_ctrl_caps_build_string_from_mask (MbimCtrlCaps mask);
GType mbim_ready_info_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_READY_INFO_FLAG (mbim_ready_info_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_READY_INFO_FLAG_IS_FLAGS__

/**
 * mbim_ready_info_flag_build_string_from_mask:
 * @mask: bitmask of MbimReadyInfoFlag values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimReadyInfoFlag in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_ready_info_flag_build_string_from_mask (MbimReadyInfoFlag mask);
GType mbim_provider_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PROVIDER_STATE (mbim_provider_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_PROVIDER_STATE_IS_FLAGS__

/**
 * mbim_provider_state_build_string_from_mask:
 * @mask: bitmask of MbimProviderState values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimProviderState in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.2
 */
gchar *mbim_provider_state_build_string_from_mask (MbimProviderState mask);
GType mbim_registration_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_REGISTRATION_FLAG (mbim_registration_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_REGISTRATION_FLAG_IS_FLAGS__

/**
 * mbim_registration_flag_build_string_from_mask:
 * @mask: bitmask of MbimRegistrationFlag values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimRegistrationFlag in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_registration_flag_build_string_from_mask (MbimRegistrationFlag mask);
GType mbim_ip_configuration_available_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_IP_CONFIGURATION_AVAILABLE_FLAG (mbim_ip_configuration_available_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_IP_CONFIGURATION_AVAILABLE_FLAG_IS_FLAGS__

/**
 * mbim_ip_configuration_available_flag_build_string_from_mask:
 * @mask: bitmask of MbimIPConfigurationAvailableFlag values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimIPConfigurationAvailableFlag in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.0
 */
gchar *mbim_ip_configuration_available_flag_build_string_from_mask (MbimIPConfigurationAvailableFlag mask);
GType mbim_sms_status_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_STATUS_FLAG (mbim_sms_status_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_STATUS_FLAG_IS_FLAGS__

/**
 * mbim_sms_status_flag_build_string_from_mask:
 * @mask: bitmask of MbimSmsStatusFlag values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimSmsStatusFlag in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.4
 */
gchar *mbim_sms_status_flag_build_string_from_mask (MbimSmsStatusFlag mask);
GType mbim_frequency_range_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_FREQUENCY_RANGE (mbim_frequency_range_get_type ())

/* Define type-specific symbols */
#define __MBIM_FREQUENCY_RANGE_IS_FLAGS__

/**
 * mbim_frequency_range_build_string_from_mask:
 * @mask: bitmask of MbimFrequencyRange values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimFrequencyRange in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.28
 */
gchar *mbim_frequency_range_build_string_from_mask (MbimFrequencyRange mask);
GType mbim_subscriber_ready_status_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SUBSCRIBER_READY_STATUS_FLAG (mbim_subscriber_ready_status_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_SUBSCRIBER_READY_STATUS_FLAG_IS_FLAGS__

/**
 * mbim_subscriber_ready_status_flag_build_string_from_mask:
 * @mask: bitmask of MbimSubscriberReadyStatusFlag values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimSubscriberReadyStatusFlag in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.28
 */
gchar *mbim_subscriber_ready_status_flag_build_string_from_mask (MbimSubscriberReadyStatusFlag mask);
GType mbim_data_class_v3_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DATA_CLASS_V3 (mbim_data_class_v3_get_type ())

/* Define type-specific symbols */
#define __MBIM_DATA_CLASS_V3_IS_FLAGS__

/**
 * mbim_data_class_v3_build_string_from_mask:
 * @mask: bitmask of MbimDataClassV3 values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimDataClassV3 in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.28
 */
gchar *mbim_data_class_v3_build_string_from_mask (MbimDataClassV3 mask);
GType mbim_data_subclass_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DATA_SUBCLASS (mbim_data_subclass_get_type ())

/* Define type-specific symbols */
#define __MBIM_DATA_SUBCLASS_IS_FLAGS__

/**
 * mbim_data_subclass_build_string_from_mask:
 * @mask: bitmask of MbimDataSubclass values.
 *
 * Builds a string containing a comma-separated list of nicknames for
 * each #MbimDataSubclass in @mask.
 *
 * Returns: (transfer full): a string with the list of nicknames, or %NULL if none given. The returned value should be freed with g_free().
 *
 * Since: 1.28
 */
gchar *mbim_data_subclass_build_string_from_mask (MbimDataSubclass mask);
G_END_DECLS

#endif /* __LIBMBIM_GLIB_FLAG_TYPES_H__ */

/* Generated data ends here */

